import {Component, ElementRef, ViewChild} from '@angular/core';
import axios from "axios";
import {DevelopmentStore} from "../../store/DevelopmentStore";
import {FormsModule} from "@angular/forms";
import {NgIf} from "@angular/common";

@Component({
  selector: 'app-download',
  standalone: true,
  imports: [
    FormsModule,
    NgIf
  ],
  templateUrl: './download.component.html',
  styleUrl: './download.component.scss'
})
export class DownloadComponent {

  @ViewChild('download_not_possible') download_not_possible: ElementRef<HTMLDialogElement> | undefined;

  inputFileId: string = "";
  fileId: string = "";
  filePassword: string = "";
  downloadInfo: DownloadInfo | null = null;


  constructor(private developmentStore: DevelopmentStore) {
    this.speedTest();
  }

  checkFile() {

    console.log(this.inputFileId);
    this.fileId = this.inputFileId; // TODO: Implement link extraction logic

    this.getDownloadInfo();
  }

  checkPassword() {

  }

  private speedTest() {
    const start = new Date().getTime(); // Start timer

    axios({
      method: 'get',
      url: this.developmentStore.getBaseUrl() + 'api/v1/speed-test',
      responseType: 'arraybuffer',
      headers: {
        'Access-Control-Allow-Origin': '*', // Allow CORS
      }
    })
      .then(response => {
        const end = new Date().getTime(); // End timer
        const duration = (end - start) / 1000; // Convert ms to seconds
        const bitsLoaded = response.data.byteLength * 8;
        const speedBps = bitsLoaded / duration;
        const speedKbps = speedBps / 1024;
        const speedMbps = speedKbps / 1024;
        console.log(`Download speed: ${speedMbps.toFixed(2)} Mbps`);
      })
      .catch(error => {
        console.error('Error during download test:', error);
      });
  }

  private getDownloadInfo() {
    axios({
      method: 'get',
      url: this.developmentStore.getBaseUrl() + 'api/v1/download-info?fileId=' + this.fileId,
      responseType: 'json',
      headers: {
        'Access-Control-Allow-Origin': '*', // Allow CORS
      }
    })
    .then(response => {
      this.downloadInfo = response.data;
      console.log(response.data);
      return response.data;
    })
    .catch(error => {
      console.error('Error during download info request:', error);
    });
  }
}
interface DownloadInfo {
  downloadable: boolean;
  passwordProtected: boolean;
  singleDownload: boolean;
  fileId: string;
}
